@@ -3,7 +3,7 @@ import heapq
 from abc import ABC, abstractmethod
 from collections.abc import Iterable, Sequence
 from dataclasses import replace
-from datetime import date, datetime, time, timezone
+from datetime import datetime
 from functools import reduce
 from typing import Any, Generic, Literal, cast, overload
 
@@ -48,7 +48,6 @@ class Timeline(ABC, Generic[IvlOut]):
         Accepts:
         - int: Passed through as-is (Unix timestamp)
         - datetime: Must be timezone-aware, converted to timestamp
-        - date: Converted to start/end of day in UTC
         - None: Unbounded (passed through)
 
         Raises:
@@ -61,27 +60,21 @@ class Timeline(ABC, Generic[IvlOut]):
         if isinstance(bound, datetime):
             if bound.tzinfo is None:
                 raise TypeError(
-                    f"Timeline slice {edge} bound must be a timezone-aware datetime.\n"
+                    f"Timeline slice {edge} must be a timezone-aware datetime.\n"
                     f"Got naive datetime: {bound!r}\n"
                     f"Hint: Add timezone info:\n"
-                    f"  dt = datetime(..., tzinfo=timezone.utc)"
+                    f"  dt = datetime(..., tzinfo=timezone.utc)\n"
+                    f"  from zoneinfo import ZoneInfo\n"
+                    f"  dt = datetime(..., tzinfo=ZoneInfo('US/Pacific'))"
                 )
             return int(bound.timestamp())
-        if isinstance(bound, date):
-            # Convert date to datetime at start/end of day in UTC
-            if edge == "start":
-                dt = datetime.combine(bound, time.min, tzinfo=timezone.utc)
-            else:  # edge == "end"
-                dt = datetime.combine(bound, time.max, tzinfo=timezone.utc)
-            return int(dt.timestamp())
         raise TypeError(
-            f"Timeline slice {edge} bound must be int, datetime, date, or None.\n"
+            f"Timeline slice {edge} must be int, timezone-aware datetime, or None.\n"
             f"Got {type(bound).__name__!r}: {bound!r}\n"
             f"Examples:\n"
             f"  timeline[start_ts:end_ts]  # int (Unix seconds)\n"
             f"  timeline[datetime(2025,1,1,tzinfo=timezone.utc):]  "
             f"# timezone-aware datetime\n"
-            f"  timeline[date(2025,1,1):date(2025,12,31)]  # date objects"
         )
 
     @overload
